clear all
*Commands used: search eq5dds

****************************************
*1/TORORO: CLEANING DATABASES
****************************************
****************************************
import excel "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Tororo/Tororo_alldata_modified_final.xlsx", sheet("Data") firstrow
drop if missing(part_astudy_id)
replace part_astudy_id = "T1404 AJ2" in 79
replace part_astudy_id = "T417 OJ2" in 111
replace part_astudy_id = "T418 ARM2" in 113
replace part_astudy_id = "T910 NJ2" in 219
sort part_astudy_id part_aage part_asex
quietly by part_astudy_id part_aage part_asex:  gen dup = cond(_N==1,0,_n)
drop if dup==2
drop dup
rename SubmissionDate submissiondate
rename metainstanceID metainstanceid
rename KEY key
rename SubmitterID submitterid

*Omit observations without data
drop if missing(part_astudy_id)
*Create infection variables
replace SmAD3="." if missing(SmAD3)
destring SmAD3, replace
*ge Smansoni=0
*replace Smansoni=1 if KK_epg_max>0
*replace Smansoni=. if missing(SmAD1) & missing(SmBD1) & missing(SmAD2) & missing(SmBD2) & missing(SmAD3) & missing(SmBD3)
*Infection intensity: light infection(epg<100)=1; moderate infection(epg 100-399)=2; heavy infection(epg>=400)=3
ge Infection_intensity=0
replace Infection_intensity=1 if KK_epg_max>0 & KK_epg_max<100
replace Infection_intensity=2 if KK_epg_max>99 & KK_epg_max<400
replace Infection_intensity=3 if KK_epg_max>399
*Fixing variables: infected, coinfected, malaria, Hb, weight and height
replace weight=64.4 if weight==644
ge bmi = weight/(height)^2
ge infected_all=0
replace infected_all=1 if malaria_yn==1 | Smansoni==1 | Hookworm==1 | Ascaris==1 | Other_infection==1
ge malaria_temp=0
replace malaria_temp=1 if malaria_yn==1
ge coinfected = malaria_temp+Smansoni+Hookworm+Ascaris+Other_infection
replace coinfected=. if missing(malaria_yn) & missing(Smansoni) & missing(Hookworm) & missing(Ascaris) & missing(Other_infection)
drop malaria_temp

replace coinfected=0 if missing(coinfected)
tab coinfected

*Fixing symptoms variables and TABs
*Three most common symptoms: symptomsdiarrhoea=171, symptomsblood_stool=29, symptomspain_urine=86, symptomsabdominal_pain=226, symptomsnausea=114, symptomsvomiting=134, symptomsfever=251, symptomschills=147, symptomsheadache=308, symptomsrash=146, symptomsmuscle_pain=69, symptomsdiff_breath=46, symptomsdizziness=80, symptomsweakness=146, symptomsbody_swelling=28
replace symptomsdiarrhoea_groupdiarrhoea=0 if symptomsdiarrhoea==0
replace symptomsblood_stool_groupblood_s=0 if symptomsblood_stool==0
replace symptomspain_urine_grouppain_uri=0 if symptomspain_urine==0
replace symptomsabdomen_pain_groupabdomi=0 if symptomsabdominal_pain==0
replace symptomsnausea_groupnausea_sever=0 if symptomsnausea==0
replace symptomsvomiting_groupvomiting_s=0 if symptomsvomiting==0
replace symptomsfever_groupfever_severit=0 if symptomsfever==0
replace symptomschills_groupchills_sever=0 if symptomschills==0
replace symptomsheadache_groupheadache_s=0 if symptomsheadache==0
replace symptomsrash_grouprash_severity=0 if symptomsrash==0
replace symptomsmuscle_pain_groupmuscle_=0 if symptomsmuscle_pain==0
replace symptomsdiff_breath_groupdiff_br=0 if symptomsdiff_breath==0
replace symptomsdizziness_groupdizziness=0 if symptomsdizziness==0
replace symptomsweakness_groupweakness_s=0 if symptomsweakness==0
replace symptomsbody_swelling_groupbody_=0 if symptomsbody_swelling==0
replace v46=0 if symptomsdiarrhoea==0
replace v49=0 if symptomsblood_stool==0
replace v52=0 if symptomspain_urine==0
replace v55=0 if symptomsabdominal_pain==0
replace symptomsnausea_groupnausea_days=0 if symptomsnausea==0
replace symptomsvomiting_groupvomiting_d=0 if symptomsvomiting==0
replace symptomsfever_groupfever_days=0 if symptomsfever==0
replace symptomschills_groupchills_days=0 if symptomschills==0
replace symptomsheadache_groupheadache_d=0 if symptomsheadache==0
replace symptomsrash_grouprash_days=0 if symptomsrash==0
replace v76=0 if symptomsmuscle_pain==0
replace v79=0 if symptomsdiff_breath==0
replace v82=0 if symptomsdizziness==0
replace symptomsweakness_groupweakness_d=0 if symptomsweakness==0
replace v88=0 if symptomsbody_swelling==0
**********************************************
*WASH and SES VARIABLES
**********************************************
rename household_caharacteristics_group material_floor
rename v138 material_floor_other
rename v139 material_roof
rename v140 material_roof_other
rename v141 material_walls
rename v142 material_walls_other
rename v143 rooms_sleeping
rename v144 farm_land
rename v145 cattle
rename v146 horses
rename v147 goats
rename v148 pigs
rename v149 chicken
rename v150 ducks
rename v151 turkeys
rename v152 other_animals
rename v153 other_animals_number
rename v154 assets
rename v155 cooking_fuel
rename v156 cooking_fuel_other
rename v157 drinking_water_source
rename v158 drinking_water_source_other
rename v159 drinking_water_time
rename v160 drinking_water_insecurity
rename v161 non_drinking_source
rename v162 non_drinking_source_other
rename v163 non_drinking_time
rename v164 non_drinking_safe
rename v165 non_drinking_safe_other
rename v166 latrine_location
rename v167 latrine_usage
rename v168 latrine_usage_other
rename v169 landing_site
rename v170 communal_latrines
rename v171 communal_latrines_usage
rename v172 open_defaecation
rename v173 education_campaign
replace rooms_sleeping=2 if rooms_sleeping==23
ge watch=0 
replace watch=1 if strpos(assets, "1")
ge mobile=0 
replace mobile=1 if strpos(assets, "2")
ge bicyle=0 
replace bicyle=1 if strpos(assets, "3")
ge radio=0 
replace radio=1 if strpos(assets, "4")
ge tv=0 
replace tv=1 if strpos(assets, "5")
ge motorcycle=0 
replace motorcycle=1 if strpos(assets, "6")
ge animal_cart=0 
replace animal_cart=1 if strpos(assets, "7")
ge car=0 
replace car=1 if strpos(assets, "8")
ge boat_simple=0 
replace boat_simple=1 if strpos(assets, "9")
ge boat_motor=0 
replace boat_motor=1 if strpos(assets, "10")
*SES:
mca material_floor material_roof material_walls rooms_sleeping mobile bicyle radio
estat coordinates, norm(principal)
predict score, norm(principal)
xtile ses = -score, nq(3)
ge study_site=2
save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Tororo_all.dta", replace

****************************************
*2/BUGOTO: CLEANING DATABASES
****************************************
****************************************
clear all
*SCH and STH infections
import excel "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Elias excels/Bug2022_KK_results_as_hardcopies_not_ordered_EKP_SA.xlsx", sheet("Sheet1") cellrange(A1:BB1231) firstrow
drop if missing(ID)
quietly bys ID:  gen dup = cond(_N==1,0,_n)
collapse Smansoni Hookworm Ascaris Hymenolepisnana Enterobiusvermicularis Trichuristrichiura dup, by(ID)
replace Smansoni=1 if Smansoni !=0
replace Hookworm=1 if Hookworm !=0
replace Ascaris=1 if Ascaris !=0
replace Hymenolepisnana=1 if Hymenolepisnana !=0
replace Enterobiusvermicularis=1 if Enterobiusvermicularis !=0
replace Trichuristrichiura=1 if Trichuristrichiura !=0
drop dup
drop if ID==222149
rename ID part_astudy_id
sort part_astudy_id
save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta", replace
****************************************
*Adding CCA/CAA to SCH and STH
clear 
import excel "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Elias excels/Bugoto_EPG_CCA_CAA.xlsx", sheet("Sheet1") cellrange(A1:W556) firstrow
drop if missing(Participant_ID)
rename Participant_ID part_astudy_id
*Infection intensity: light infection(epg<100)=1; moderate infection(epg 100-399)=2; heavy infection(epg>=400)=3
ge Infection_intensity=0
replace Infection_intensity=1 if KK_epg_max>0 & KK_epg_max<100
replace Infection_intensity=2 if KK_epg_max>99 & KK_epg_max<400
replace Infection_intensity=3 if KK_epg_max>399
sort part_astudy_id
merge part_astudy_id using "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta"
drop _merge
sort part_astudy_id
*Making sure all infected with Smansoni are identified:
replace Smansoni=1 if KK_epg_max!=0
replace Smansoni=0 if KK_epg_max==0
save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta", replace
****************************************
*Adding the above to the Health and Economic Survey:
clear
import delimited "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Health-economic-survey-3.1.csv"
*Drop missing observations:
drop if part_astudy_id==.
drop if part_astudy_id==0
drop if part_astudy_id==1234
sort part_astudy_id
/*Rename variables
rename v21 mal_health_cond_malaria_test_cost
rename v23 mal_health_cond_malaria_treat_cost
rename v24 mal_health_cond_malaria_transport
rename v25 mal_health_cond_malaria_transport_cost
rename v29 mal_health_cond_malaria_mosquito_net_sleeping
rename v30 mal_health_cond_mosquito_net_obtained 
rename v31 mal_health_cond_mosquito_net_cost
rename v35 mal_health_cond_malaria_prev_cost
rename v37 mal_health_cond_specify
rename v38 mal_health_cond_drugs
rename v39 mal_health_cond_cost
rename v40 mal_health_cond_illness
rename v41 mal_health_cond_illness_specify
rename v42 mal_health_cond_illness_drug
rename v43 mal_health_cond_illness_cost
rename v46 symptoms_diarrhoea_days
rename v49 symptoms_blood_stool_days
rename v52 symptoms_pain_urine_days
rename v55 symptoms_abdominal_pain_days
rename v76 symptoms_muscle_pain_severity
rename v79 symptoms_diff_breath_days
rename v82 symptoms_dizziness_days
rename v88 symptoms_body_swelling_days
rename v92 care_costs_group_healer_fees
rename v93 care_costs_group_healer_treat_cost
rename v94 care_costs_group_healer_travel_mode
rename v95 care_costs_group_healer_travel_time
rename v96 care_costs_group_healer_travel_cost
rename v104 care_costs_group_hf_travel_cost
rename v109 care_costs_group_hf_admission_days
rename v110 care_costs_group_hf_admission_calls
rename v111 care_costs_group_hf_admission_food
rename v114 care_costs_group_pharmacy_test
rename v115 care_costs_group_pharmacy_treat
rename v116 care_costs_group_pharmacy_travel_mode
rename v117 care_costs_group_pharmacy_travel_time
rename v118 care_costs_group_pharmacy_travel_cost
rename v123 care_costs_group_activity_lost_time
rename v124 care_costs_group_activity_lost_cost
rename v132 hrqol_children_mobility
rename v133 hrqol_children_care
rename v134 hrqol_children_usual
rename v135 hrqol_children_pain
rename v136 hrqol_children_worried
rename v138 household_caharacteristics_material_floor_other
rename v139 household_caharacteristics_material_roof
rename v140 household_caharacteristics_material_roof_other
rename v141 household_caharacteristics_material_walls
rename v142 household_caharacteristics_material_walls_other
rename v143 household_caharacteristics_rooms_sleeping
rename v144 household_caharacteristics_farm_land
rename v145 household_caharacteristics_cattle
rename v146 household_caharacteristics_horses
rename v147 household_caharacteristics_goats
rename v148 household_caharacteristics_pigs
rename v149 household_caharacteristics_chicken
rename v150 household_caharacteristics_ducks
rename v151 household_caharacteristics_turkeys
rename v152 household_caharacteristics_other_animals
rename v153 household_caharacteristics_other_animals_number
rename v154 household_caharacteristics_assets
rename v155 household_caharacteristics_cooking_fuel
rename v156 household_caharacteristics_cooking_fuel_other
rename v157 household_caharacteristics_drinking_water_source
rename v158 household_caharacteristics_drinking_water_source_other
rename v159 household_caharacteristics_drinking_water_time
rename v160 household_caharacteristics_drinking_water_insecurity
rename v161 household_caharacteristics_non_drinking_source
rename v162 household_caharacteristics_non_drinking_source_other
rename v163 household_caharacteristics_non_drinking_time
rename v164 household_caharacteristics_non_drinking_safe
rename v165 household_caharacteristics_non_drinking_safe_other
rename v166 household_caharacteristics_latrine_location
rename v167 household_caharacteristics_latrine_usage
rename v168 household_caharacteristics_latrine_usage_other
rename v169 household_caharacteristics_landing_site
rename v170 household_caharacteristics_communal_latrines
rename v171 household_caharacteristics_communal_latrines_usage
rename v172 household_caharacteristics_open_defaecation
rename v173 household_caharacteristics_education_campaign*/
*Merge all with the remaining data (biometrics, hb and treatments)
merge part_astudy_id using "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/May2022_malaria_hb_biomx_treat.dta"
rename _merge _merge1
sort part_astudy_id
merge part_astudy_id using "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta"
tostring part_astudy_id, replace
sort part_astudy_id
drop _merge
rename houseold household
save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta", replace
sort part_astudy_id part_aage part_asex
quietly by part_astudy_id part_aage part_asex:  gen dup = cond(_N==1,0,_n)
drop if dup!=0
drop dup

*Fixing variables: infected, coinfected, malaria, Hb, weight and height
ge malaria_yn =.
replace malaria_yn=0 if malariaNP=="N"
replace malaria_yn=1 if malariaNP=="P" | malariaNP=="PP" | malariaNP=="PPP"
ge death=0
replace death=1 if part_astudy_id=="22082"
replace Hb=143 if part_astudy_id=="22253"
replace weight=10.9 if part_astudy_id=="22013"
ge bmi = weight/(height)^2
ge infected_all=0
replace infected_all=1 if malaria_yn==1 | Smansoni==1 | Hookworm==1 | Ascaris==1 | Hymenolepisnana==1 | Enterobiusvermicularis==1 | Trichuristrichiura==1
ge malaria_temp=0
replace malaria_temp=1 if malaria_yn==1
ge coinfected = malaria_temp+Smansoni+Hookworm+Ascaris+Hymenolepisnana+Enterobiusvermicularis+Trichuristrichiura
replace coinfected=. if missing(malaria_yn) & missing(Smansoni) & missing(Hookworm) & missing(Ascaris) & missing(Hymenolepisnana) & missing(Enterobiusvermicularis) & missing(Trichuristrichiura)
drop malaria_temp

*Fixing symptoms variables
*Three most common symptoms: symptomsheadache, symptomsabdominal_pain and symptomsdiarrhoea 
replace symptomsdiarrhoea_groupdiarrhoea=0 if symptomsdiarrhoea==0
replace symptomsblood_stool_groupblood_s=0 if symptomsblood_stool==0
replace symptomspain_urine_grouppain_uri=0 if symptomspain_urine==0
replace symptomsabdomen_pain_groupabdomi=0 if symptomsabdominal_pain==0
replace symptomsnausea_groupnausea_sever=0 if symptomsnausea==0
replace symptomsvomiting_groupvomiting_s=0 if symptomsvomiting==0
replace symptomsfever_groupfever_severit=0 if symptomsfever==0
replace symptomschills_groupchills_sever=0 if symptomschills==0
replace symptomsheadache_groupheadache_s=0 if symptomsheadache==0
replace symptomsrash_grouprash_severity=0 if symptomsrash==0
replace symptomsmuscle_pain_groupmuscle_=0 if symptomsmuscle_pain==0
replace symptomsdiff_breath_groupdiff_br=0 if symptomsdiff_breath==0
replace symptomsdizziness_groupdizziness=0 if symptomsdizziness==0
replace symptomsweakness_groupweakness_s=0 if symptomsweakness==0
replace symptomsbody_swelling_groupbody_=0 if symptomsbody_swelling==0

replace v46=0 if symptomsdiarrhoea==0
replace v49=0 if symptomsblood_stool==0
replace v52=0 if symptomspain_urine==0
replace v55=0 if symptomsabdominal_pain==0
replace symptomsnausea_groupnausea_days=0 if symptomsnausea==0
replace symptomsvomiting_groupvomiting_d=0 if symptomsvomiting==0
replace symptomsfever_groupfever_days=0 if symptomsfever==0
replace symptomschills_groupchills_days=0 if symptomschills==0
replace symptomsheadache_groupheadache_d=0 if symptomsheadache==0
replace symptomsrash_grouprash_days=0 if symptomsrash==0
replace v76=0 if symptomsmuscle_pain==0
replace v79=0 if symptomsdiff_breath==0
replace v82=0 if symptomsdizziness==0
replace symptomsweakness_groupweakness_d=0 if symptomsweakness==0
replace v88=0 if symptomsbody_swelling==0

**********************************************
*WASH and SES VARIABLES
**********************************************
rename household_caharacteristics_group material_floor
rename v138 material_floor_other
rename v139 material_roof
rename v140 material_roof_other
rename v141 material_walls
rename v142 material_walls_other
rename v143 rooms_sleeping
rename v144 farm_land
rename v145 cattle
rename v146 horses
rename v147 goats
rename v148 pigs
rename v149 chicken
rename v150 ducks
rename v151 turkeys
rename v152 other_animals
rename v153 other_animals_number
rename v154 assets
rename v155 cooking_fuel
rename v156 cooking_fuel_other
rename v157 drinking_water_source
rename v158 drinking_water_source_other
rename v159 drinking_water_time
rename v160 drinking_water_insecurity
rename v161 non_drinking_source
rename v162 non_drinking_source_other
rename v163 non_drinking_time
rename v164 non_drinking_safe
rename v165 non_drinking_safe_other
rename v166 latrine_location
rename v167 latrine_usage
rename v168 latrine_usage_other
rename v169 landing_site
rename v170 communal_latrines
rename v171 communal_latrines_usage
rename v172 open_defaecation
rename v173 education_campaign
replace rooms_sleeping=2 if rooms_sleeping==23
ge watch=0 
replace watch=1 if strpos(assets, "1")
ge mobile=0 
replace mobile=1 if strpos(assets, "2")
ge bicyle=0 
replace bicyle=1 if strpos(assets, "3")
ge radio=0 
replace radio=1 if strpos(assets, "4")
ge tv=0 
replace tv=1 if strpos(assets, "5")
ge motorcycle=0 
replace motorcycle=1 if strpos(assets, "6")
ge animal_cart=0 
replace animal_cart=1 if strpos(assets, "7")
ge car=0 
replace car=1 if strpos(assets, "8")
ge boat_simple=0 
replace boat_simple=1 if strpos(assets, "9")
ge boat_motor=0 
replace boat_motor=1 if strpos(assets, "10")
*SES:
mca material_floor material_roof material_walls rooms_sleeping mobile bicyle radio
estat coordinates, norm(principal)
predict score, norm(principal)
xtile ses = -score, nq(3)
ge study_site=1
save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta", replace

****************************************
****************************************
*APPEND DATASETS
****************************************
append using "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Tororo_all.dta" "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/Bugoto_all.dta", force

sort part_astudy_id part_aage part_asex
quietly by part_astudy_id part_aage part_asex:  gen dup = cond(_N==1,0,_n)
drop if dup==2
drop dup part_aheight part_aweight part_amuac status deviceid Initials SubmitterName AttachmentsPresent AttachmentsExpected Status ReviewState DeviceID Edits FormVersion QN submittername attachmentspresent attachmentsexpected reviewstate formversion edits _merge1 ID
tostring CCA1 CCA2 CCA3 SmAD1 SmBD1 SmAD2 SmBD2 SmAD3 SmBD3, replace
replace CCA1=POCCCA_1 if CCA1=="."
replace CCA2=POCCCA_2 if CCA2=="."
replace CCA3=POCCCA_3 if CCA3=="."
replace SmAD1=KK_1_A if SmAD1=="."
replace SmBD1=KK_1_B if SmBD1=="."
replace SmAD2=KK_2_A if SmAD2=="."
replace SmBD2=KK_2_B if SmBD2=="."
replace SmAD3=KK_3_A if SmAD3=="."
replace SmBD3=KK_3_B if SmBD3=="."
replace CCA1="." if CCA1=="NA"
replace CCA2="." if CCA2=="NA"
replace CCA3="." if CCA3=="NA"
replace SmAD1="." if SmAD1=="NA"
replace SmBD1="." if SmBD1=="NA"
replace SmAD2="." if SmAD2=="NA"
replace SmBD2="." if SmBD2=="NA"
replace SmAD3="." if SmAD3=="NA"
replace SmBD3="." if SmBD3=="NA"
drop heightcm armcircumference POCCCA_1 POCCCA_2 POCCCA_3 POCCCA_rep2 POCCCA_rep3 KK_1_A KK_1_B KK_2_A KK_2_B KK_3_A KK_3_B

ge Schisto_infection_CCA=0
replace Schisto_infection_CCA=1 if CCAmean>=3
replace Schisto_infection_CCA=. if missing(CCAmean)
ge Other_helm_infection=.
replace Other_helm_infection=1 if Hookworm==1 | Ascaris==1 | Hymenolepisnana==1 | Enterobiusvermicularis==1 | Trichuristrichiura==1 | Other_infection==1
replace Other_helm_infection=0 if Hookworm==0 & Ascaris==0 & Hymenolepisnana==0 & Enterobiusvermicularis==0 & Trichuristrichiura==0 & study_site==1
replace Other_helm_infection=0 if Other_infection==0 & study_site==2
replace infected_all=. if Smansoni==. & malaria_yn==. & Other_helm_infection==.
replace coinfected=. if Smansoni==. & malaria_yn==. & Other_helm_infection==.

	label variable part_asex "Sex"
	label define part_asexl 0 "Male" 1 "Female"
	label values part_asex part_asexl
	label variable study_site "Study site" 
	label define study_sitel 1 "Mayuge" 2 "Tororo"
	label values study_site study_sitel
generate education=0
replace education=0 if part_aeducation=="none"
replace education=1 if part_aeducation=="primary"
replace education=2 if part_aeducation=="secondary" | part_aeducation=="higher"
	label variable education "Education"
	label define educationl 0 "None" 1 "Primary" 2 "Secondary or higher"
	label values education educationl
ge marital_status=1
replace marital_status=2 if part_amarital_status==2 | part_amarital_status==3
replace marital_status=3 if part_amarital_status==4 | part_amarital_status==5
	label variable marital_status "Marital status"
	label define marital_statusl 1 "Single/never married" 2 "Married or living together" 3 "Divorced/separated/widowed"
	label values marital_status marital_statusl 
ge occupation=7
replace occupation=1 if part_aoccupation==1
replace occupation=2 if part_aoccupation==2
replace occupation=3 if part_aoccupation==3
replace occupation=4 if part_aoccupation==4
replace occupation=5 if part_aoccupation==5
replace occupation=6 if part_aoccupation==11
	label variable occupation "Education"
	label define occupationl 1 "Unemployed" 2 "Student/child" 3 "Farmer" 4 "Fishfolk" 5 "Sales" 6 "Housewife" 7 "Other"
	label values occupation occupationl
generate age_category=.
replace age_category=1 if part_aage<18
replace age_category=2 if part_aage>=18 & part_aage<35
replace age_category=3 if part_aage>=35 & part_aage<55
replace age_category=4 if part_aage>55
	label variable age_category "Age category"
	label define age_categoryl 1 "<18" 2 "18-34" 3 "35-54" 4 ">55"
	label values age_category age_categoryl


	
********************************************************************************
********************************************************************************
*** CONSIDERING ONLY PARTICIPANTS >=8 YEARS OF AGE
********************************************************************************
********************************************************************************
drop if part_aage<8
save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/BugandTo_final.dta", replace

****************************************
*3/ HRQoL: create common variables for adults and children and health states
****************************************
****************************************

*Checking adults HRQoL:
tab hrqolhrqol_adulthrqol_adult_stat
recode hrqolhrqol_adulthrqol_adult_stat 1000 = 100
*1 is no problem and 5 is unable:
tab hrqolhrqol_adulthrqol_adult_mobi
tab hrqolhrqol_adulthrqol_adult_care
tab hrqolhrqol_adulthrqol_adult_usua
tab hrqolhrqol_adulthrqol_adult_pain
tab hrqolhrqol_adulthrqol_adult_anxi

*Checking children HRQoL:
tab hrqolhrqol_childrenhrqol_childre
recode hrqolhrqol_childrenhrqol_childre 1000 = 100
recode hrqolhrqol_childrenhrqol_childre 701 = 70
recode hrqolhrqol_childrenhrqol_childre 565 = 55
*1 is no problem and 5 is unable:
tab v132
tab v133
tab v134
tab v135
tab v136

*Creating the self-reported health states:
*This is a variable with 5 characters and in each one 1 to 5 values regarding each of the health dimensions
egen hs_adults=concat(hrqolhrqol_adulthrqol_adult_mobi hrqolhrqol_adulthrqol_adult_care hrqolhrqol_adulthrqol_adult_usua hrqolhrqol_adulthrqol_adult_pain hrqolhrqol_adulthrqol_adult_anxi)
egen hs_children=concat(v132 v133 v134 v135 v136)
ge hs=.
tostring hs, ge(hs_all)
replace hs_all= hs_adults
replace hs_all= hs_children if hs_all=="....."
drop hs
tab hs_all
drop if strpos(hs_all, ".")>0

*Visualising the ten most common states
tab hs_all, sort

*Adding HRQoL of children and adults
ge hrqol_scale_all=.
replace hrqol_scale_all= hrqolhrqol_adulthrqol_adult_stat
replace hrqol_scale_all=hrqolhrqol_childrenhrqol_childre if missing(hrqol_scale_all)

ge hrqol_mobi_all=.
replace hrqol_mobi_all= hrqolhrqol_adulthrqol_adult_mobi
replace hrqol_mobi_all=v132 if missing(hrqol_mobi_all)

ge hrqol_care_all=.
replace hrqol_care_all= hrqolhrqol_adulthrqol_adult_care
replace hrqol_care_all=v133 if missing(hrqol_care_all)

ge hrqol_usua_all=.
replace hrqol_usua_all= hrqolhrqol_adulthrqol_adult_usua
replace hrqol_usua_all=v134 if missing(hrqol_usua_all)

ge hrqol_pain_all=.
replace hrqol_pain_all= hrqolhrqol_adulthrqol_adult_pain
replace hrqol_pain_all=v135 if missing(hrqol_pain_all)

ge hrqol_anxi_all=.
replace hrqol_anxi_all= hrqolhrqol_adulthrqol_adult_anxi
replace hrqol_anxi_all=v136 if missing(hrqol_anxi_all)

save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/BugandTo_final.dta", replace


****************************************
*Descriptive eq5dds: https://journals.sagepub.com/doi/pdf/10.1177/1536867X1601600309
*part_asex=1 when female (0 is male)
*part_aage
eq5dds hrqol_mobi_all hrqol_care_all hrqol_usua_all hrqol_pain_all hrqol_anxi_all hrqol_scale_all, version(5L) counts
eq5dds hrqol_mobi_all hrqol_care_all hrqol_usua_all hrqol_pain_all hrqol_anxi_all hrqol_scale_all, version(5L) counts by(part_asex)

eq5dds hrqol_mobi_all hrqol_care_all hrqol_usua_all hrqol_pain_all hrqol_anxi_all hrqol_scale_all, version(5L) counts by(part_asex) graph
hist hrqol_scale_all
drop if study_site==2
tab hs_all, sort
eq5dds hrqol_mobi_all hrqol_care_all hrqol_usua_all hrqol_pain_all hrqol_anxi_all, version(5L) graph
hist hrqol_scale_all
use "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/BugandTo_final.dta", replace
drop if study_site==1
tab hs_all, sort
hist hrqol_scale_all
eq5dds hrqol_mobi_all hrqol_care_all hrqol_usua_all hrqol_pain_all hrqol_anxi_all, version(5L) graph
use "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/BugandTo_final.dta", replace

eq5dds hrqol_mobi_all hrqol_care_all hrqol_usua_all hrqol_pain_all hrqol_anxi_all hrqol_scale_all if part_aage>50, version(5L) counts graph

tab hrqol_mobi_all
ranksum hrqol_mobi_all, by(study_site)
tab hrqol_care_all 
ranksum hrqol_care_all, by(study_site)
tab hrqol_usua_all 
ranksum hrqol_usua_all, by(study_site)
tab hrqol_pain_all 
ranksum hrqol_pain_all, by(study_site)
tab hrqol_anxi_all
ranksum hrqol_anxi_all, by(study_site)

ranksum Infection_intensity if age_category==1, by(study_site) 
ranksum Infection_intensity if age_category==2, by(study_site) 
ranksum Infection_intensity if age_category==3, by(study_site) 
ranksum Infection_intensity if age_category==4, by(study_site) 

su hrqol_scale_all if Smansoni==1
su hrqol_scale_all if Smansoni==1 &  study_site==1
su hrqol_scale_all if Smansoni==1 &  study_site==2
ranksum hrqol_scale_all if Smansoni==1, by (study_site)
ranksum hrqol_mobi_all if Smansoni==1, by (study_site)
ranksum hrqol_care_all if Smansoni==1, by (study_site)
ranksum hrqol_usua_all if Smansoni==1, by (study_site)
ranksum hrqol_pain_all if Smansoni==1, by (study_site)
ranksum hrqol_anxi_all if Smansoni==1, by (study_site)

kwallis hrqol_scale_all if study_site==1, by(age_category) 
kwallis hrqol_scale_all if study_site==2, by(age_category) 


*The level sum score (LSS) 
****EQ-5D-5L values (Uganda value set) plotted against the LSS
gen lss_adults= hrqolhrqol_adulthrqol_adult_mobi + hrqolhrqol_adulthrqol_adult_care + hrqolhrqol_adulthrqol_adult_usua + hrqolhrqol_adulthrqol_adult_pain + hrqolhrqol_adulthrqol_adult_anxi
replace lss_adults=0 if missing(lss_adults)
gen lss_children= v132 + v133 + v134 + v135 + v136
replace lss_children=0 if missing(lss_children)
gen lss_all = lss_adults + lss_children

***Define EQ-5D-5L value set for Uganda (https://pubmed.ncbi.nlm.nih.gov/34841471/)
sca MO1=1
sca MO2=0.073
sca MO3=0.146
sca MO4=0.245
sca MO5=0.376
sca SC1=1
sca SC2=0.068
sca SC3=0.110
sca SC4=0.240
sca SC5=0.354
sca UA1=1
sca UA2=0.060
sca UA3=0.081
sca UA4=0.243
sca UA5=0.306
sca PD1=1
sca PD2=0.082
sca PD3=0.138
sca PD4=0.580
sca PD5=0.798
sca AD1=1
sca AD2=0.050
sca AD3=0.127
sca AD4=0.235
sca AD5=0.282

*EQ-5D5L index values: Generate the EQ-5D5L values of sample according to Uganda value set
*I did it manually but there is also a command:
*https://euroqol.org/wp-content/uploads/2019/06/EuroQol-Working-Paper-Series-19001-Juan-M.-Ramos-Goni.pdf

forvalues i = 1(1)5 {
	ge mo`i'=`i' if hrqolhrqol_adulthrqol_adult_mobi==`i' | v132==`i'
	ge sc`i'= `i' if hrqolhrqol_adulthrqol_adult_care==`i' | v133==`i'
	ge ua`i'= `i' if hrqolhrqol_adulthrqol_adult_usua==`i' | v134==`i'
	ge pd`i'= `i' if hrqolhrqol_adulthrqol_adult_pain==`i' | v135==`i'
	ge ad`i'= `i' if hrqolhrqol_adulthrqol_adult_anxi==`i' | v136==`i'
}

forvalues i = 1(1)5 {
	ge v_mo`i'= mo`i' * MO`i'
	replace v_mo`i'=0 if missing(v_mo`i')
	ge v_sc`i'= sc`i' * SC`i'
	replace v_sc`i'=0 if missing(v_sc`i')
	ge v_ua`i'= ua`i' * UA`i'
	replace v_ua`i'=0 if missing(v_ua`i')
	ge v_pd`i'= pd`i' * PD`i'
	replace v_pd`i'=0 if missing(v_pd`i')
	ge v_ad`i'= ad`i' * AD`i'
	replace v_ad`i'=0 if missing(v_ad`i')
}

gen value = 1 - v_mo2 - v_mo3 - v_mo4 - v_mo5 - v_sc2 - v_sc3 - v_sc4 - v_sc5 - v_ua2 - v_ua3 - v_ua4 - v_ua5 - v_pd2 - v_pd3 - v_pd4 - v_pd5 - v_ad2 - v_ad3 - v_ad4 - v_ad5

tab value
ranksum value, by(study_site)
su value if Smansoni==1
su value if Smansoni==1 &  study_site==1
su value if Smansoni==1 &  study_site==2

*Graph plotting values and against lss_all
twoway (scatter value lss_all)

****************************************
*Cumulative frequencies of health states:
destring hs_all, replace
sort hs_all
by hs_all, sort: gen freq = _N
by hs_all: gen cumfreq = _N if _n == 1
replace cumfreq = sum(cumfreq)
tabdisp hs_all, cell(freq cumfreq)
glcurve hs_all, lorenz 

****************************************
*Descriptive statistics
****************************************
*Socio-demographic characteristics
bys study_site: tab part_aage
tab part_aage
bys study_site: tab part_asex
tab part_asex
bys study_site: tab part_amarital_status
tab part_amarital_status
bys study_site: tab part_aeducation
tab part_aeducation
bys study_site: tab part_aoccupation
tab part_aoccupation
bys study_site: tab non_drinking_source
tab non_drinking_source
bys study_site: tab latrine_location
tab latrine_location
tab material_roof

*Infection status
bys study_site: tab Smansoni
tab Smansoni
bys study_site: tab Schisto_infection_CCA
tab Schisto_infection_CCA
bys study_site: tab Infection_intensity
tab Infection_intensity
bys study_site: tab malaria_yn
tab malaria_yn
bys study_site: tab Other_helm_infection
tab Other_helm_infection
bys study_site: tab infected_all
tab infected_all
bys study_site: tab coinfected
tab coinfected

tab CCAmean
su bmi,d
su Hb,d

*EQ-5D responses
bys study_site: su hrqol_scale_all 
su hrqol_scale_all 
bys study_site: su hrqol_mobi_all 
su hrqol_mobi_all 
bys study_site: su hrqol_care_all 
su hrqol_care_all 
bys study_site: su hrqol_usua_all 
su hrqol_usua_all 
bys study_site: su hrqol_pain_all 
su hrqol_pain_all 
bys study_site: su hrqol_anxi_all
su hrqol_anxi_all

bys age_category: su hrqol_scale_all
bys age_category: tab hrqol_mobi_all
bys age_category: tab hrqol_care_all
bys age_category: tab hrqol_usua_all
bys age_category: tab hrqol_pain_all
bys age_category: tab hrqol_anxi_all

ge anaemia=0
replace anaemia=1 if Hb<130 & part_asex==0 & part_aage>14
replace anaemia=1 if Hb<120 & part_asex==1 & part_aage>11
replace anaemia=1 if Hb<120 & part_asex==0 & part_aage>11 & part_aage<15
replace anaemia=1 if Hb<115 & part_aage<12
replace anaemia=. if Hb==.

save "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/BugandTo_final.dta", replace
****************************************
*5/ REGRESSION ANALYSIS
****************************************
****************************************
*Determinants of EQVAS:
reg hrqol_scale_all i.hrqol_mobi_all i.hrqol_care_all i.hrqol_usua_all i.hrqol_pain_all i.hrqol_anxi_all
reg hrqol_scale_all i.hrqol_mobi_all i.hrqol_care_all i.hrqol_usua_all i.hrqol_pain_all i.hrqol_anxi_all if study_site==2
reg hrqol_scale_all i.hrqol_mobi_all i.hrqol_care_all i.hrqol_usua_all i.hrqol_pain_all i.hrqol_anxi_all if study_site==1

*Significant at 5% anxiety and pain to a lesser extent. Significant at 10% care and mobility to a lesser extent. Not signicant usual activities.

* Distribution of the EQ-5D Values
hist value
hist value if study_site==1
hist value if study_site==2
histogram value, frequency by(study_site, col(1))
swilk value

*Check age and infection:
bys age_category: su value
bys age_category: su value if Smansoni==1
bys age_category: su value if coinfected==1
bys age_category: su value if malaria_yn==1

*Some graphs to check for age and infection
graph bar (count) Infection, over(age_category) by(study_site)
graph bar (count) Smansoni, over(age_category) by(study_site)

*EQ-5D-5L data were transposed into a utility decrement using "decrement = 1 - utility". The decrements were used as dependent variables in the regression model
*hrqol_scale_all
*Choosing independent variable:
*************!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!Spearman's Correlation using Stata
reg value part_aage
reg value bmi
reg value infected_all /*Significant but unable to capture the true sign of both variables*/
reg value coinfected  /*Significant but unable to capture the true sign of both variables*/
reg value part_asex   /*Not significant*/
*Education, marital status and occupation: not significant
reg value Hb
reg value symptomsdiarrhoea_groupdiarrhoea /*Signficant only at 10%*/
reg symptomsblood_stool_groupblood_s
reg value symptomspain_urine_grouppain_uri
reg value symptomschills_groupchills_sever /*Signficant only at 10%*/
reg value symptomsheadache_groupheadache_s
reg value symptomsmuscle_pain_groupmuscle_
reg value symptomsweakness_groupweakness_s
reg value symptomsbody_swelling_groupbody_
*Not significant: reg value symptomsabdomen_pain_groupabdomi, symptomsnausea_groupnausea_sever, symptomsvomiting_groupvomiting_s, symptomsfever_groupfever_severit, symptomsrash_grouprash_severity, symptomsdiff_breath_groupdiff_br, reg value symptomsdizziness_groupdizziness
reg value hrqol_scale_all

*Spearman's correlation:
spearman value part_aage 	/*significant*/
spearman value part_asex 	/*female compare to male has reduced value*/
spearman value bmi			/*significant*/
spearman value Smansoni		
spearman value Schisto_infection_CCA
spearman value malaria_yn
spearman value Infection_intensity
spearman value infected_all
spearman value coinfected
spearman value Hb
spearman value mal_health_condhealth_conditions
spearman value symptomsdiarrhoea_groupdiarrhoea /*Signficant*/
spearman value symptomsblood_stool_groupblood_s
spearman value symptomspain_urine_grouppain_uri /*Signficant*/
spearman value symptomschills_groupchills_sever /*Signficant*/
spearman value symptomsheadache_groupheadache_s /*Signficant*/
spearman value symptomsmuscle_pain_groupmuscle_ /*Signficant*/
spearman value symptomsweakness_groupweakness_s /*Signficant*/
spearman value symptomsbody_swelling_groupbody_ /*Signficant*/
spearman value symptomsabdomen_pain_groupabdomi /*Signficant*/
spearman value hrqol_scale_all /*Signficant*/
spearman value score
spearman value ses /*Signficant*/
spearman value education /*Signficant*/
spearman value occupation /*Signficant*/
spearman value marital_status /*Signficant*/
spearman value non_drinking_source
spearman value latrine_location

*HRQoL and coinfections
*Smansoni and malaria
tab value if Smansoni==1 & malaria_yn==1
su value if Smansoni==1
su value if Smansoni==1 & malaria_yn==1
*Smansoni and other helminthic infections
tab value if Smansoni==1 & Other_helm_infection==1
su value if Smansoni==1
su value if Smansoni==1 & Other_helm_infection==1


use "/Users/sergialonso/Documents/Research/Glasgow/Study proposals/EQ5D schisto Mayuge and Tororo/BugandTo_final.dta", replace


reg value part_aage part_asex infected_all Hb symptomsdiarrhoea_groupdiarrhoea symptomsheadache_groupheadache_s symptomsabdomen_pain_groupabdomi study_site
reg value part_aage part_asex symptomsdiarrhoea_groupdiarrhoea symptomspain_urine_grouppain_uri symptomschills_groupchills_sever symptomsheadache_groupheadache_s symptomsmuscle_pain_groupmuscle_ symptomsweakness_groupweakness_s symptomsbody_swelling_groupbody_ symptomsabdomen_pain_groupabdomi study_site ses i.education i.occupation i.marital_status

*glm value part_aage part_asex infected_all Hb symptomsdiarrhoea_groupdiarrhoea symptomsheadache_groupheadache_s symptomsabdomen_pain_groupabdomi, family(gamma) link(log) vce(bootstrap)

tobit value part_aage i.part_asex Hb symptomsdiarrhoea_groupdiarrhoea symptomsheadache_groupheadache_s symptomsabdomen_pain_groupabdomi, ul(1) vce(boot)

tobit value part_aage i.part_asex Hb symptomsdiarrhoea_groupdiarrhoea symptomsheadache_groupheadache_s symptomsblood_stool_groupblood_s symptomsabdomen_pain_groupabdomi symptomspain_urine_grouppain_uri symptomsmuscle_pain_groupmuscle_ symptomsweakness_groupweakness_s symptomsbody_swelling_groupbody_, ul(1) vce(boot)

tobit value part_aage part_asex symptomsdiarrhoea_groupdiarrhoea symptomspain_urine_grouppain_uri symptomschills_groupchills_sever symptomsheadache_groupheadache_s symptomsmuscle_pain_groupmuscle_ symptomsweakness_groupweakness_s symptomsbody_swelling_groupbody_ symptomsabdomen_pain_groupabdomi study_site ses i.education i.occupation i.marital_status, ul(1) vce(boot)

tobit value part_aage part_asex symptomsdiarrhoea_groupdiarrhoea symptomspain_urine_grouppain_uri symptomschills_groupchills_sever symptomsheadache_groupheadache_s symptomsmuscle_pain_groupmuscle_ symptomsweakness_groupweakness_s symptomsbody_swelling_groupbody_ symptomsabdomen_pain_groupabdomi study_site ses i.education i.occupation i.marital_status, ul(1) vce(boot)

*Final model:
tobit value part_aage part_asex symptomsdiarrhoea_groupdiarrhoea symptomspain_urine_grouppain_uri symptomschills_groupchills_sever symptomsheadache_groupheadache_s symptomsmuscle_pain_groupmuscle_ symptomsweakness_groupweakness_s symptomsbody_swelling_groupbody_ symptomsabdomen_pain_groupabdomi study_site ses i.education i.occupation, ul(1) vce(boot)

*Autocorrelation:
cor part_aage part_asex symptomsdiarrhoea_groupdiarrhoea symptomspain_urine_grouppain_uri symptomschills_groupchills_sever symptomsheadache_groupheadache_s symptomsmuscle_pain_groupmuscle_ symptomsweakness_groupweakness_s symptomsbody_swelling_groupbody_ symptomsabdomen_pain_groupabdomi study_site ses education occupation marital_status



*Testing differences: Hypotheses 2 and 3
ttesti 492 0.863 0.2 552 0.538 0.89
ttesti 492 75 15.8 552 72.1 18.8
ttesti 492 179 36.4 552 236 42.1
ttesti 492 313 63.6 552 316 57.9
tabi 396 414 \ 63 101 \ 28 35 \ 5 9 \ 0 1, chi2
tabi 479 439 \ 7 103 \ 5 15 \ 1 1 \ 0 2, chi2
tabi 389 379 \ 68 140 \ 26 36 \ 9 4 \ 0 1, chi2
tabi 257 284 \ 148 176 \ 71 76 \ 16 21 \ 0 3, chi2
tabi 293 363 \ 140 149 \ 39 36 \ 20 9 \ 0 3, chi2


*HRQoL and co-infections
tab value if Smansoni==1 & malaria_yn==1
su value if Smansoni==1 & Other_helm_infection==1 
su value if Smansoni==1 & Other_helm_infection==1 & malaria_yn==1

save QoL_Uganda_final, replace
